/*
 */

#ifndef NEXUS_API_NXS_PROPERTYS_H_
#define NEXUS_API_NXS_PROPERTYS_H_

#ifdef __cplusplus
#include <string>
#include <vector>
#endif

#include <nexus-api/nxs.h>

#define NEXUS_API_GENERATE_PROP_ENUM
#include <nexus-api/_nxs_propertys.h>
#define NEXUS_API_GENERATE_PROP_MAP
#include <nexus-api/_nxs_propertys.h>
#define NEXUS_API_GENERATE_PROP_TYPE
#include <nexus-api/_nxs_propertys.h>

#endif /* NEXUSAPI_NXS_PROPERTYS_H_ */
