struct cpuinfo_mock_file filesystem[] = {
	{
		.path = "/proc/cpuinfo",
		.size = 298,
		.content = "Processor\t: ARMv7 Processor rev 0 (v7l)\n"
			   "processor\t: 0\n"
			   "BogoMIPS\t: 313.53\n"
			   "\n"
			   "Features\t: swp half thumb fastmult vfp edsp thumbee neon vfpv3 tls \n"
			   "CPU implementer\t: 0x41\n"
			   "CPU architecture: 7\n"
			   "CPU variant\t: 0x3\n"
			   "CPU part\t: 0xc09\n"
			   "CPU revision\t: 0\n"
			   "\n"
			   "Hardware\t: PXA988\n"
			   "Revision\t: 0007\n"
			   "Serial\t\t: 4102dcf646581100\n",
	},
	{
		.path = "/system/build.prop",
		.size = 2680,
		.content =
			"# begin build properties\n"
			"# autogenerated by buildinfo.sh\n"
			"ro.build.id=JZO54K\n"
			"ro.build.display.id=JZO54K.T210LKLUANB4\n"
			"ro.build.version.incremental=T210LKLUANB4\n"
			"ro.build.version.sdk=16\n"
			"ro.build.version.codename=REL\n"
			"ro.build.version.release=4.1.2\n"
			"ro.build.date=Fri Feb 21 13:04:33 KST 2014\n"
			"ro.build.date.utc=1392955473\n"
			"ro.build.type=user\n"
			"ro.build.user=se.infra\n"
			"ro.build.host=R0210-11\n"
			"ro.build.tags=release-keys\n"
			"ro.product.model=SM-T210L\n"
			"ro.product.brand=samsung\n"
			"ro.product.name=lt02wifilgt\n"
			"ro.product.device=lt02wifilgt\n"
			"ro.product.board=PXA986\n"
			"ro.product.cpu.abi=armeabi-v7a\n"
			"ro.product.cpu.abi2=armeabi\n"
			"ro.product_ship=true\n"
			"ro.product.manufacturer=samsung\n"
			"ro.product.locale.language=en\n"
			"ro.product.locale.region=GB\n"
			"ro.wifi.channels=\n"
			"ro.board.platform=mrvl\n"
			"ro.build.PDA=T210LKLUANB4\n"
			"ro.bootloader=T210LKLUANB4\n"
			"ril.sw_ver=\n"
			"ril.official_cscver=I8268CHNALK2\n"
			"ro.build.changelist=1520441\n"
			"ro.build.modelname=SM-T210L\n"
			"# ro.build.product is obsolete; use ro.product.device\n"
			"ro.build.product=lt02wifilgt\n"
			"# Do not try to parse ro.build.description or .fingerprint\n"
			"ro.build.description=lt02wifilgt-user 4.1.2 JZO54K T210LKLUANB4 release-keys\n"
			"ro.build.fingerprint=samsung/lt02wifilgt/lt02wifilgt:4.1.2/JZO54K/T210LKLUANB4:user/release-keys\n"
			"ro.build.characteristics=tablet\n"
			"# end build properties\n"
			"#\n"
			"# system.prop for nevocmcc\n"
			"#\n"
			"\n"
			"# System property for Default Brightness\n"
			"ro.lcd_brightness=195\n"
			"ro.sf.lcd_density=160\n"
			"\n"
			"# minimum brightness value\n"
			"ro.lcd_min_brightness=20\n"
			"\n"
			"# rotation setting in potrait mode.\n"
			"ro.sf.hwrotation=270\n"
			"\n"
			"ro.kernel.qemu=0\n"
			"\n"
			"#LGU ContentManager main root directory\n"
			"ro.lgu.contentmanager=/storage/extSdCard\n"
			"\n"
			"ro.carrier=wifi-only\n"
			"\n"
			"# System property for Font Clarity\n"
			"persist.sys.font_clarity=0\n"
			"\n"
			"#\n"
			"# ADDITIONAL_BUILD_PROPERTIES\n"
			"#\n"
			"keyguard.no_require_sim=1\n"
			"persist.service.blcr.enable=0\n"
			"persist.sys.tools.enable=0\n"
			"ro.wifi.active_roaming.enable=true\n"
			"ro.tel.config.path=/system/etc/tel/\n"
			"ro.sf.lcd_density=240\n"
			"ro.carrier=unknown\n"
			"ro.com.google.clientidbase=android-samsung\n"
			"dalvik.vm.heapstartsize=8m\n"
			"dalvik.vm.heapgrowthlimit=64m\n"
			"dalvik.vm.heapsize=256m\n"
			"ro.sec.fle.encryption=true\n"
			"ro.config.ringtone=S_Over_the_horizon.ogg\n"
			"ro.config.notification_sound=S_Whistle.ogg\n"
			"ro.config.alarm_alert=Walk_in_the_forest.ogg\n"
			"ro.config.media_sound=Media_preview_Touch_the_light.ogg\n"
			"ro.config.voip_dvfs_freq=3\n"
			"ro.error.receiver.default=com.samsung.receiver.error\n"
			"ro.tvout.enable=false\n"
			"ro.com.google.apphider=off\n"
			"ro.com.google.clientidbase.ms=android-lgu-kr\n"
			"ro.com.google.clientidbase.am=android-lgu-kr\n"
			"ro.com.google.clientidbase.yt=android-samsung\n"
			"ro.com.google.clientidbase.gmm=android-samsung\n"
			"ro.com.google.gmsversion=4.1_r6\n"
			"boot.fps=9\n"
			"net.bt.name=Android\n"
			"dalvik.vm.stack-trace-file=/data/anr/traces.txt\n"
			"\n",
	},
	{
		.path = "/sys/devices/system/cpu/kernel_max",
		.size = 2,
		.content = "1\n",
	},
	{
		.path = "/sys/devices/system/cpu/possible",
		.size = 4,
		.content = "0-1\n",
	},
	{
		.path = "/sys/devices/system/cpu/present",
		.size = 4,
		.content = "0-1\n",
	},
	{
		.path = "/sys/devices/system/cpu/online",
		.size = 2,
		.content = "0\n",
	},
	{
		.path = "/sys/devices/system/cpu/offline",
		.size = 2,
		.content = "1\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpuidle/current_driver",
		.size = 12,
		.content = "pxa988_idle\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpuidle/current_governor_ro",
		.size = 5,
		.content = "menu\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu0/cpufreq/affected_cpus",
		.size = 2,
		.content = "0\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu0/cpufreq/cpuinfo_max_freq",
		.size = 8,
		.content = "1205000\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu0/cpufreq/cpuinfo_min_freq",
		.size = 7,
		.content = "312000\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu0/cpufreq/cpuinfo_transition_latency",
		.size = 6,
		.content = "10000\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu0/cpufreq/related_cpus",
		.size = 2,
		.content = "0\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu0/cpufreq/scaling_available_frequencies",
		.size = 31,
		.content = "312000 624000 1066000 1205000 \n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu0/cpufreq/scaling_available_governors",
		.size = 67,
		.content = "interactive conservative ondemand powersave userspace performance \n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu0/cpufreq/scaling_cur_freq",
		.size = 7,
		.content = "312000\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu0/cpufreq/scaling_driver",
		.size = 15,
		.content = "pxa988-cpufreq\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu0/cpufreq/scaling_governor",
		.size = 9,
		.content = "ondemand\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu0/cpufreq/scaling_min_freq",
		.size = 7,
		.content = "312000\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu0/cpufreq/stats/time_in_state",
		.size = 51,
		.content = "312000 11572\n"
			   "624000 789\n"
			   "1066000 1053\n"
			   "1205000 10056\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu0/cpufreq/stats/total_trans",
		.size = 4,
		.content = "762\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu0/cpufreq/stats/trans_table",
		.size = 277,
		.content = "   From  :    To\n"
			   "         :    312000    624000   1066000   1205000 \n"
			   "   312000:         0         0        23       105 \n"
			   "   624000:        60         0         7        50 \n"
			   "  1066000:        36        55         0       135 \n"
			   "  1205000:        33        62       196         0 \n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu0/topology/physical_package_id",
		.size = 2,
		.content = "0\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu0/topology/core_siblings_list",
		.size = 4,
		.content = "0-1\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu0/topology/core_siblings",
		.size = 2,
		.content = "3\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu0/topology/core_id",
		.size = 2,
		.content = "0\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu0/topology/thread_siblings_list",
		.size = 2,
		.content = "0\n",
	},
	{
		.path = "/sys/devices/system/cpu/cpu0/topology/thread_siblings",
		.size = 2,
		.content = "1\n",
	},
	{NULL},
};

#ifdef __ANDROID__
struct cpuinfo_mock_property properties[] = {
	{
		.key = "android.telephony.apn-restore",
		.value = "600000",
	},
	{
		.key = "boot.fps",
		.value = "9",
	},
	{
		.key = "dalvik.vm.heapgrowthlimit",
		.value = "64m",
	},
	{
		.key = "dalvik.vm.heapsize",
		.value = "256m",
	},
	{
		.key = "dalvik.vm.heapstartsize",
		.value = "8m",
	},
	{
		.key = "dalvik.vm.stack-trace-file",
		.value = "/data/anr/traces.txt",
	},
	{
		.key = "dev.MDPLimitCondition",
		.value = "0",
	},
	{
		.key = "dev.bootcomplete",
		.value = "1",
	},
	{
		.key = "dev.kiessupport",
		.value = "TRUE",
	},
	{
		.key = "drm.service.enabled",
		.value = "true",
	},
	{
		.key = "gsm.current.phone-type",
		.value = "1",
	},
	{
		.key = "gsm.operator.alpha",
		.value = "LG U+",
	},
	{
		.key = "gsm.operator.iso-country",
		.value = "kr",
	},
	{
		.key = "gsm.operator.isroaming",
		.value = "false",
	},
	{
		.key = "gsm.operator.numeric",
		.value = "45006",
	},
	{
		.key = "gsm.sim.operator.alpha",
		.value = "LG U+",
	},
	{
		.key = "gsm.sim.operator.iso-country",
		.value = "kr",
	},
	{
		.key = "gsm.sim.operator.numeric",
		.value = "45006",
	},
	{
		.key = "init.svc.BCS-daemon",
		.value = "running",
	},
	{
		.key = "init.svc.DR-daemon",
		.value = "running",
	},
	{
		.key = "init.svc.DTT-daemon",
		.value = "running",
	},
	{
		.key = "init.svc.FMRadiod",
		.value = "running",
	},
	{
		.key = "init.svc.KIES-daemon",
		.value = "running",
	},
	{
		.key = "init.svc.PowerDaemon",
		.value = "running",
	},
	{
		.key = "init.svc.SMD-daemon",
		.value = "running",
	},
	{
		.key = "init.svc.adbd",
		.value = "running",
	},
	{
		.key = "init.svc.atcmdsrv-aponly",
		.value = "running",
	},
	{
		.key = "init.svc.bootanim",
		.value = "stopped",
	},
	{
		.key = "init.svc.dbus",
		.value = "running",
	},
	{
		.key = "init.svc.debuggerd",
		.value = "running",
	},
	{
		.key = "init.svc.diag-aponly",
		.value = "running",
	},
	{
		.key = "init.svc.drm",
		.value = "running",
	},
	{
		.key = "init.svc.filemonitor",
		.value = "running",
	},
	{
		.key = "init.svc.flash_recovery",
		.value = "stopped",
	},
	{
		.key = "init.svc.installd",
		.value = "running",
	},
	{
		.key = "init.svc.keystore",
		.value = "running",
	},
	{
		.key = "init.svc.macloader",
		.value = "stopped",
	},
	{
		.key = "init.svc.marvelltel",
		.value = "stopped",
	},
	{
		.key = "init.svc.media",
		.value = "running",
	},
	{
		.key = "init.svc.mobex-daemon",
		.value = "running",
	},
	{
		.key = "init.svc.mwirelessd",
		.value = "running",
	},
	{
		.key = "init.svc.netd",
		.value = "running",
	},
	{
		.key = "init.svc.nvm-aponly",
		.value = "running",
	},
	{
		.key = "init.svc.p2p_supplicant",
		.value = "running",
	},
	{
		.key = "init.svc.powersnd",
		.value = "stopped",
	},
	{
		.key = "init.svc.ril-daemon",
		.value = "stopped",
	},
	{
		.key = "init.svc.sdcard",
		.value = "running",
	},
	{
		.key = "init.svc.sensord",
		.value = "running",
	},
	{
		.key = "init.svc.servicemanager",
		.value = "running",
	},
	{
		.key = "init.svc.setup_fs",
		.value = "stopped",
	},
	{
		.key = "init.svc.simal",
		.value = "running",
	},
	{
		.key = "init.svc.surfaceflinger",
		.value = "running",
	},
	{
		.key = "init.svc.ueventd",
		.value = "running",
	},
	{
		.key = "init.svc.vold",
		.value = "running",
	},
	{
		.key = "init.svc.wpa_supplicant",
		.value = "running",
	},
	{
		.key = "init.svc.zygote",
		.value = "running",
	},
	{
		.key = "keyguard.no_require_sim",
		.value = "1",
	},
	{
		.key = "marvell.ril.ppp.enabled",
		.value = "0",
	},
	{
		.key = "net.bt.name",
		.value = "Android",
	},
	{
		.key = "net.change",
		.value = "net.qtaguid_enabled",
	},
	{
		.key = "net.hostname",
		.value = "android-181009c45f5a0089",
	},
	{
		.key = "net.qtaguid_enabled",
		.value = "1",
	},
	{
		.key = "net.tcp.buffersize.default",
		.value = "4096,87380,110208,4096,16384,110208",
	},
	{
		.key = "net.tcp.buffersize.edge",
		.value = "4093,26280,35040,4096,16384,35040",
	},
	{
		.key = "net.tcp.buffersize.gprs",
		.value = "4092,8760,11680,4096,8760,11680",
	},
	{
		.key = "net.tcp.buffersize.hspa",
		.value = "4094,87380,262144,4096,16384,262144",
	},
	{
		.key = "net.tcp.buffersize.lte",
		.value = "524288,1048576,2097152,262144,524288,1048576",
	},
	{
		.key = "net.tcp.buffersize.umts",
		.value = "4094,87380,110208,4096,16384,110208",
	},
	{
		.key = "net.tcp.buffersize.wifi",
		.value = "524288,1048576,2097152,262144,524288,1048576",
	},
	{
		.key = "persist.audio.allsoundmute",
		.value = "0",
	},
	{
		.key = "persist.audio.apmaster",
		.value = "1",
	},
	{
		.key = "persist.audio.codecmaster",
		.value = "0",
	},
	{
		.key = "persist.audio.gsspmaster",
		.value = "1",
	},
	{
		.key = "persist.audio.headsetsysvolume",
		.value = "4",
	},
	{
		.key = "persist.audio.hphonesysvolume",
		.value = "4",
	},
	{
		.key = "persist.audio.ringermode",
		.value = "2",
	},
	{
		.key = "persist.audio.sysvolume",
		.value = "4",
	},
	{
		.key = "persist.bt.pcmmaster",
		.value = "0",
	},
	{
		.key = "persist.radio.pcmmaster",
		.value = "1",
	},
	{
		.key = "persist.service.blcr.enable",
		.value = "0",
	},
	{
		.key = "persist.sys.country",
		.value = "US",
	},
	{
		.key = "persist.sys.flipfontpath",
		.value = "default",
	},
	{
		.key = "persist.sys.font_clarity",
		.value = "0",
	},
	{
		.key = "persist.sys.language",
		.value = "en",
	},
	{
		.key = "persist.sys.localevar",
		.value = "",
	},
	{
		.key = "persist.sys.profiler_ms",
		.value = "0",
	},
	{
		.key = "persist.sys.rotation.animation",
		.value = "0",
	},
	{
		.key = "persist.sys.setupwizard",
		.value = "FINISH",
	},
	{
		.key = "persist.sys.storage_preload",
		.value = "2",
	},
	{
		.key = "persist.sys.timezone",
		.value = "Asia/Seoul",
	},
	{
		.key = "persist.sys.tools.enable",
		.value = "0",
	},
	{
		.key = "persist.sys.usb.config",
		.value = "mtp,adb",
	},
	{
		.key = "ril.approved_codever",
		.value = "none",
	},
	{
		.key = "ril.approved_cscver",
		.value = "none",
	},
	{
		.key = "ril.official_cscver",
		.value = "T210LLGTANB4",
	},
	{
		.key = "ril.servicestate",
		.value = "1",
	},
	{
		.key = "ril.sw_ver",
		.value = "",
	},
	{
		.key = "ril.tethering.usb.active",
		.value = "0",
	},
	{
		.key = "rild.libpath",
		.value = "/system/lib/libmarvell-ril.so",
	},
	{
		.key = "ro.allow.mock.location",
		.value = "0",
	},
	{
		.key = "ro.baseband",
		.value = "unknown",
	},
	{
		.key = "ro.bluetooth.dun",
		.value = "true",
	},
	{
		.key = "ro.board.platform",
		.value = "mrvl",
	},
	{
		.key = "ro.boot.emmc_checksum",
		.value = "3",
	},
	{
		.key = "ro.boot.serialno",
		.value = "4102dcf646581100",
	},
	{
		.key = "ro.boot_recovery",
		.value = "unknown",
	},
	{
		.key = "ro.bootloader",
		.value = "T210LKLUANB4",
	},
	{
		.key = "ro.bootmode",
		.value = "unknown",
	},
	{
		.key = "ro.bt.bdaddr_path",
		.value = "/efs/bluetooth/bt_addr",
	},
	{
		.key = "ro.build.PDA",
		.value = "T210LKLUANB4",
	},
	{
		.key = "ro.build.changelist",
		.value = "1520441",
	},
	{
		.key = "ro.build.characteristics",
		.value = "tablet",
	},
	{
		.key = "ro.build.date.utc",
		.value = "1392955473",
	},
	{
		.key = "ro.build.date",
		.value = "Fri Feb 21 13:04:33 KST 2014",
	},
	{
		.key = "ro.build.description",
		.value = "lt02wifilgt-user 4.1.2 JZO54K T210LKLUANB4 release-keys",
	},
	{
		.key = "ro.build.display.id",
		.value = "JZO54K.T210LKLUANB4",
	},
	{
		.key = "ro.build.fingerprint",
		.value = "samsung/lt02wifilgt/lt02wifilgt:4.1.2/JZO54K/T210LKLUANB4:user/release-keys",
	},
	{
		.key = "ro.build.host",
		.value = "R0210-11",
	},
	{
		.key = "ro.build.id",
		.value = "JZO54K",
	},
	{
		.key = "ro.build.modelname",
		.value = "SM-T210L",
	},
	{
		.key = "ro.build.product",
		.value = "lt02wifilgt",
	},
	{
		.key = "ro.build.tags",
		.value = "release-keys",
	},
	{
		.key = "ro.build.type",
		.value = "user",
	},
	{
		.key = "ro.build.user",
		.value = "se.infra",
	},
	{
		.key = "ro.build.version.codename",
		.value = "REL",
	},
	{
		.key = "ro.build.version.incremental",
		.value = "T210LKLUANB4",
	},
	{
		.key = "ro.build.version.release",
		.value = "4.1.2",
	},
	{
		.key = "ro.build.version.sdk",
		.value = "16",
	},
	{
		.key = "ro.carrier",
		.value = "wifi-only",
	},
	{
		.key = "ro.com.google.apphider",
		.value = "off",
	},
	{
		.key = "ro.com.google.clientidbase.am",
		.value = "android-lgu-kr",
	},
	{
		.key = "ro.com.google.clientidbase.gmm",
		.value = "android-samsung",
	},
	{
		.key = "ro.com.google.clientidbase.ms",
		.value = "android-lgu-kr",
	},
	{
		.key = "ro.com.google.clientidbase.yt",
		.value = "android-samsung",
	},
	{
		.key = "ro.com.google.clientidbase",
		.value = "android-samsung",
	},
	{
		.key = "ro.com.google.gmsversion",
		.value = "4.1_r6",
	},
	{
		.key = "ro.config.alarm_alert",
		.value = "Walk_in_the_forest.ogg",
	},
	{
		.key = "ro.config.media_sound",
		.value = "Media_preview_Touch_the_light.ogg",
	},
	{
		.key = "ro.config.notification_sound",
		.value = "S_Whistle.ogg",
	},
	{
		.key = "ro.config.ringtone",
		.value = "S_Over_the_horizon.ogg",
	},
	{
		.key = "ro.config.voip_dvfs_freq",
		.value = "3",
	},
	{
		.key = "ro.cp_debug_level",
		.value = "unknown",
	},
	{
		.key = "ro.crypto.state",
		.value = "unencrypted",
	},
	{
		.key = "ro.csc.country_code",
		.value = "KOREA",
	},
	{
		.key = "ro.csc.countryiso_code",
		.value = "WW",
	},
	{
		.key = "ro.csc.sales_code",
		.value = "LGT",
	},
	{
		.key = "ro.debug_level",
		.value = "0x4f4c",
	},
	{
		.key = "ro.debuggable",
		.value = "0",
	},
	{
		.key = "ro.emmc",
		.value = "unknown",
	},
	{
		.key = "ro.emmc_checksum",
		.value = "3",
	},
	{
		.key = "ro.error.receiver.default",
		.value = "com.samsung.receiver.error",
	},
	{
		.key = "ro.factorytest",
		.value = "0",
	},
	{
		.key = "ro.hardware",
		.value = "pxa988",
	},
	{
		.key = "ro.kernel.qemu",
		.value = "0",
	},
	{
		.key = "ro.lcd_brightness",
		.value = "195",
	},
	{
		.key = "ro.lcd_min_brightness",
		.value = "20",
	},
	{
		.key = "ro.lgu.contentmanager",
		.value = "/storage/extSdCard",
	},
	{
		.key = "ro.marvell.platform.type",
		.value = "TTC_TD",
	},
	{
		.key = "ro.media.gst.enabled",
		.value = "1",
	},
	{
		.key = "ro.nfc.port",
		.value = "I2C",
	},
	{
		.key = "ro.nvdata_backup",
		.value = "unknown",
	},
	{
		.key = "ro.opengles.version",
		.value = "131072",
	},
	{
		.key = "ro.product.board",
		.value = "PXA986",
	},
	{
		.key = "ro.product.brand",
		.value = "samsung",
	},
	{
		.key = "ro.product.cpu.abi2",
		.value = "armeabi",
	},
	{
		.key = "ro.product.cpu.abi",
		.value = "armeabi-v7a",
	},
	{
		.key = "ro.product.device",
		.value = "lt02wifilgt",
	},
	{
		.key = "ro.product.locale.language",
		.value = "en",
	},
	{
		.key = "ro.product.locale.region",
		.value = "GB",
	},
	{
		.key = "ro.product.manufacturer",
		.value = "samsung",
	},
	{
		.key = "ro.product.model",
		.value = "SM-T210L",
	},
	{
		.key = "ro.product.name",
		.value = "lt02wifilgt",
	},
	{
		.key = "ro.product_ship",
		.value = "true",
	},
	{
		.key = "ro.revision",
		.value = "7",
	},
	{
		.key = "ro.runtime.firstboot",
		.value = "1325386510485",
	},
	{
		.key = "ro.sec.fle.encryption",
		.value = "true",
	},
	{
		.key = "ro.secure",
		.value = "1",
	},
	{
		.key = "ro.serialno",
		.value = "4102dcf646581100",
	},
	{
		.key = "ro.setupwizard.mode",
		.value = "OPTIONAL",
	},
	{
		.key = "ro.sf.hwrotation",
		.value = "270",
	},
	{
		.key = "ro.sf.lcd_density",
		.value = "160",
	},
	{
		.key = "ro.tel.config.path",
		.value = "/system/etc/tel/",
	},
	{
		.key = "ro.tvout.enable",
		.value = "false",
	},
	{
		.key = "ro.wifi.active_roaming.enable",
		.value = "true",
	},
	{
		.key = "ro.wifi.channels",
		.value = "",
	},
	{
		.key = "service.bootanim.exit",
		.value = "1",
	},
	{
		.key = "service.camera.af",
		.value = "1",
	},
	{
		.key = "storage.mmc.size",
		.value = "15758000128",
	},
	{
		.key = "sys.barcode",
		.value = "S210L67078752",
	},
	{
		.key = "sys.baseband",
		.value = "UMTS",
	},
	{
		.key = "sys.boot_completed",
		.value = "1",
	},
	{
		.key = "sys.factory.mediaScanningCount",
		.value = "7",
	},
	{
		.key = "sys.hw_ver",
		.value = "REV03",
	},
	{
		.key = "sys.manufacturedate",
		.value = "20140211",
	},
	{
		.key = "sys.serialnumber",
		.value = "R34F200ZR9",
	},
	{
		.key = "sys.settings_secure_version",
		.value = "4",
	},
	{
		.key = "sys.settings_system_version",
		.value = "25",
	},
	{
		.key = "sys.telephonymoduleloglevel",
		.value = "8",
	},
	{
		.key = "sys.usb.config",
		.value = "mtp,adb",
	},
	{
		.key = "sys.usb.diagmodem",
		.value = "1",
	},
	{
		.key = "sys.usb.state",
		.value = "mtp,adb",
	},
	{
		.key = "system_init.startsurfaceflinger",
		.value = "0",
	},
	{
		.key = "vold.post_fs_data_done",
		.value = "1",
	},
	{
		.key = "wifi.interface",
		.value = "wlan0",
	},
	{
		.key = "wifidirect.interface",
		.value = "p2p0",
	},
	{
		.key = "wlan.driver.status",
		.value = "ok",
	},
	{
		.key = "wlan.wfd.status",
		.value = "disconnected",
	},
	{NULL},
};
#endif /* __ANDROID__ */
